* Encoding: windows-1252.
***.

* v02 - 2020-04-14. Subtitle has been edited, and footnote has been added. Labels in French and Spanish have been removed.

***.
include "surveyname.sps".

get file = 'hl.sav'.

weight by hhweight.

* Select children who are of primary school age; this definition is
* country-specific and should be changed to reflect the situation in your
* country.

* include definition of primarySchoolEntryAge .
include 'define/MICS6 - 08 - LN.sps' .

variable labels schage "Age at beginning of school year".

select if (schage >= primarySchoolEntryAge and schage <= primarySchoolCompletionAge).

compute primary  = 0.
if (ED10A >= 1 and ED10A <= 2) primary =  100.

* Further adjust for children that are of primary school completion age and already completed primary school, but did not attend secondary.
* Set test for "Age at the begining of school year" equal to age in last grade of primary and test for ED4B equal to the last grade of primary.
if (ED5A = 1 and ED5B = primarySchoolGrades and ED6 = 1 and ED9 = 2) primary  = 100.

*Out of school children are those who did not attend school or early childhood education in the current school year and have not completed primary school (ED9=2 and ED5A=1 and ED5B=last grade of primary school and ED6<>1).
*Children for whom it is not known whether they are attending school (ED9>2), for whom level of current attendance is not known (ED10A>4), .
*or those who are likely misclassified as attending level(s) above secondary education (ED10A>3) are not considered out of school. 
*This group should consist of very few cases (missing and inconsistent values). Therefore, the results in the NAR and Out of School columns do not necessarily sum to 100.
compute notAttendingSchoolPreschool = 0 .
if (ED9 = 2 or ED4 = 2) notAttendingSchoolPreschool = 100 .
if (ED5A = 1 and ED5B = primarySchoolGrades and ED6 = 1 and ED9 = 2) notAttendingSchoolPreschool  = 0.

* Attending preschool are those who in the current school year have been attending preschool school (ED6A=0).
compute attendingPreschool = 0.
if (ED10A = 0) attendingPreschool = 100 .

* Out of school children are the sum attending preschol and not attending school.
compute outOfSchool = 0.
if (notAttendingSchoolPreschool = 100) outOfSchool = 100.

variable labels primary "".
variable labels HL4 "".

compute layer = 1.
value labels layer 1 "Percentage of children:".

compute numChildren = 1.

variable labels caretakerdis "Mother's functional difficulties [B]".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

* Ctables command in English.
ctables
  /vlabels variables = hl4 primary layer notAttendingSchoolPreschool 
                       attendingPreschool outOfSchool numChildren
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by 
           hl4 [c] > (
             primary [s][mean,'Net attendance ratio (adjusted) [1]',f5.1] 
           + layer [c] > (
               attendingPreschool [s] [mean,'Attending early childhood education',f5.1]
             + outOfSchool [s] [mean,'Out of school [A]',f5.1] )
           + numChildren [s] [validn,'Number of children of primary school age at beginning of school year'] )
  /categories variables=all empty=exclude missing=exclude
  /categories variables=hl4 total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
    "Table LN.2.3: Primary school attendance and out of school children"												
    "Percentage of children of primary school age attending primary or secondary school (adjusted net attendance ratio), percentage attending early childhood education, and percentage out of school, by sex, " + surveyname
   caption =
    "[1] MICS indicator LN.5a - Primary school net attendance ratio (adjusted)"
    "[2] MICS indicator LN.6a - Out-of-school rate for children of primary school age"																	
    "[A] The percentage of children of primary school age out of school are those not attending early childhood education, primary or lower secondary education. Children who have completed primary school are excluded."
    "[B] The disaggregate of Mother's functional difficulties is shown only for respondents to the Adult Functioning module, i.e. individually interviewed women age 18-49 years and men age 18-49 years in selected households."	
  .

new file.
